=======
Credits
=======

Development Lead
----------------

* Dmytro Litvinov <me@dmytrolitvinov.com> `@DmytroLitvinov <https://twitter.com/DmytroLitvinov>`_

Contributors
------------

* Vsevolod Lobko `@sevikkk <https://github.com/sevikkk>`_

* Dmytro Kazanzhy `@kazanzhy <https://github.com/kazanzhy>`_
